@@ -13,7 +13,7 @@ __PACKAGE__->register_color_space( 'cmy' );
 
 use Carp;
 
-our $VERSION = '0.07';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -140,11 +140,6 @@ sub new_rgb
    $class->new( 1 - $r, 1 - $g, 1 - $b );
 }
 
-# Keep perl happy; keep Britain tidy
-1;
-
-__END__
-
 =head1 SEE ALSO
 
 =over 4
@@ -166,3 +161,7 @@ L<Convert::Color::CMYK> - a color value represented as cyan/magenta/yellow/key
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
+0x55AA;
